@@ -93,6 +93,15 @@ class SortableStackedInlineBase(SortableModelAdminBase):
                     continue
 
                 fields = line.get('fields')
+
+                # Some use tuples for fields however they are immutable
+                if isinstance(fields, tuple):
+                    raise AssertionError(
+                        "The fields attribute of your Inline is a tuple. "
+                        "This must be list as we may need to modify it and "
+                        "tuples are immutable."
+                    )
+
                 if self.sortable in fields:
                     fields.remove(self.sortable)
 
