@@ -214,7 +214,8 @@ class Menu(object):
 
     def find_native_app(self, app_name):
         for app in self.app_list:
-            if app['name'].lower() == app_name:
+            _app_name = app.get('app_label', app.get('name'))
+            if _app_name.lower() == app_name:
                 return app
 
     def convert_native_app(self, native_app, app_name):
